@@ -576,6 +576,7 @@ static int sg_open_drive_fd(char *fname, int scan_mode)
 	   O_NONBLOCK was already hardcoded in ata_ but not in sg_.
 	   There must be some reason for this. So O_NONBLOCK is
 	   default mode for both now. Disable on own risk.
+           ts B10904: O_NONBLOCK is prescribed by <linux/cdrom.h>
 	   ts A70411
            Switched to O_NDELAY for LKML statement 2007/4/11/141 by Alan Cox:
 	   "open() has side effects. The CD layer allows you to open
@@ -1530,6 +1531,33 @@ int sg_grab(struct burn_drive *d)
 	   relase of drive. Unclear why not the official error return
 	   value -1 of open(2) war used. */
 	if(! burn_drive_is_open(d)) {
+		char msg[120];
+
+#ifndef Libburn_udev_wait_useC
+#define Libburn_udev_wait_useC 100000
+#endif
+
+#ifndef Libburn_udev_extra_open_cyclE
+
+	if (Libburn_udev_wait_useC > 0) {
+		/* ts B10921 : workaround for udev which might get
+				a kernel event from open() and might
+				remove links if it cannot inspect the
+				drive. This waiting period shall allow udev
+				to act after it was woken up by the drive scan
+				activities.
+		*/
+		sprintf(msg,
+	    "To avoid collision with udev: Waiting %lu usec before grabbing",
+				(unsigned long) Libburn_udev_wait_useC);
+		libdax_msgs_submit(libdax_messenger, -1, 0x00000002,
+				LIBDAX_MSGS_SEV_DEBUG, LIBDAX_MSGS_PRIO_HIGH,
+				msg, 0, 0);
+		usleep(Libburn_udev_wait_useC);
+	}
+
+#endif /* Libburn_udev_extra_open_cyclE */
+
 
 try_open:;
 		/* ts A60821
@@ -1552,6 +1580,34 @@ try_open:;
 
 		fd = open(d->devname, open_mode);
 		os_errno = errno;
+
+#ifdef Libburn_udev_extra_open_cyclE
+
+		/* ts B10920 : workaround for udev which might get
+				a kernel event from open() and might
+				remove links if it cannot inspect the
+				drive.
+		   ts B10921 : this is more obtrusive than above waiting
+				before open(). The drive scan already has
+				opened and closed the drive several times.
+				So it seems to be merely about giving an
+				opportunity to udev, before long term grabbing
+				happens.
+		*/
+		if (fd >= 0 && Libburn_udev_wait_useC > 0) {
+			close(fd);
+			sprintf(msg,
+	    "To avoid collision with udev: Waiting %lu usec before re-opening",
+				(unsigned long) Libburn_udev_wait_useC);
+			libdax_msgs_submit(libdax_messenger, -1, 0x00000002,
+				LIBDAX_MSGS_SEV_DEBUG, LIBDAX_MSGS_PRIO_HIGH,
+				msg, 0, 0);
+			usleep(Libburn_udev_wait_useC);
+			fd = open(d->devname, open_mode);
+			os_errno = errno;
+		}
+#endif /* Libburn_udev_extra_open_cyclE */
+
 		if (fd >= 0) {
 			sg_fcntl_lock(&fd, d->devname, F_WRLCK, 1);
 			if (fd < 0)
@@ -1575,6 +1631,10 @@ try_open:;
 drive_is_in_use:;
 	tries++;
 	if (tries < max_tries) {
+		libdax_msgs_submit(libdax_messenger, -1, 0x00000002,
+				LIBDAX_MSGS_SEV_DEBUG, LIBDAX_MSGS_PRIO_HIGH,
+			"Drive is in use. Waiting 2 seconds before re-try", 
+				0, 0);
 		usleep(2000000);
 		goto try_open;
 	}
@@ -1929,6 +1989,19 @@ int burn_os_stdio_capacity(char *path, off_t *bytes)
 		*bytes = add_size + ((off_t) vfsbuf.f_frsize) *
 						(off_t) vfsbuf.f_bavail;
 	}
+
+#ifdef NIX
+/* <<< */
+	fprintf(stderr, "libburn_DEBUG: Faking 4.5 TB of disk space\n");
+	*bytes = ((off_t) 2415919104) * (off_t) 2048;
+	if (*bytes / (off_t) 2048 > (off_t) 0x7ffffff0) {
+		*bytes = ((off_t) 0x7ffffff0) * (off_t) 2048;
+		fprintf(stderr, "libburn_DEBUG: Reducing disk space to 4 TB - 2 kB\n");
+	}
+/* <<< */
+#endif
+
+
 	ret = 1;
 ex:;
 	BURN_FREE_MEM(testpath);
