@@ -74,9 +74,6 @@ struct cd_mid_record {
 	int m_li;
 	int s_li;
 	int f_li;
-	int m_lo;
-	int s_lo;
-	int f_lo;
 	char *other_brands;
 };
 typedef struct cd_mid_record cd_mid_record_t;
@@ -91,51 +88,51 @@ char *burn_guess_cd_manufacturer(int m_li, int s_li, int f_li,
                                  int m_lo, int s_lo, int f_lo, int flag)
 {
 	static cd_mid_record_t mid_list[]= {
-	{"SKC",                                 96, 40,  0,  0, 0, 0, ""},
-	{"Ritek Corp"                         , 96, 43, 30,  0, 0, 0, ""},
-	{"TDK / Ritek"                        , 97, 10,  0,  0, 0, 0, "TRAXDATA"},
-	{"TDK Corporation"                    , 97, 15,  0,  0, 0, 0, ""},
-	{"Ritek Corp"                         , 97, 15, 10,  0, 0, 0, "7-plus, Aopen, PONY, Power Source, TDK, TRAXDATA, HiCO, PHILIPS, Primdisc, Victor.JVC, OPTI STORAGE, Samsung"},
-	{"Mitsubishi Chemical Corporation"    , 97, 15, 20,  0, 0, 0, ""},
-	{"Nan-Ya Plastics Corporation"        , 97, 15, 30,  0, 0, 0, "Hatron, MMore, Acer, LITEON"},
-	{"Delphi"                             , 97, 15, 50,  0, 0, 0, ""},
-	{"Shenzhen SG&SAST"                   , 97, 16, 20,  0, 0, 0, ""},
-	{"Moser Baer India Limited"           , 97, 17,  0,  0, 0, 0, "EMTEC, Intenso, YAKUMO, PLATINUM, Silver Circle"},
-	{"SKY media Manufacturing SA"         , 97, 17, 10,  0, 0, 0, ""},
-	{"Wing"                               , 97, 18, 10,  0, 0, 0, ""},
-	{"DDT"                                , 97, 18, 20,  0, 0, 0, ""},
-	{"Daxon Technology Inc. / Acer"       , 97, 22, 60,  0, 0, 0, "Maxmax, Diamond Data, BenQ, gold, SONY"},
-	{"Taiyo Yuden Company Limited"        , 97, 24,  0,  0, 0, 0, "Maxell, FUJIFILM, SONY"},
-	{"Sony Corporation"                   , 97, 24, 10,  0, 0, 0, "LeadData, Imation"},
-	{"Computer Support Italcard s.r.l"    , 97, 24, 20,  0, 0, 0, ""},
-	{"Unitech Japan Inc."                 , 97, 24, 30,  0, 0, 0, ""},
-	{"MPO, France"                        , 97, 25,  0,  0, 0, 0, "TDK"},
-	{"Hitachi Maxell Ltd."                , 97, 25, 20,  0, 0, 0, ""},
-	{"Infodisc Technology Co,Ltd."        , 97, 25, 30,  0, 0, 0, "MEMOREX, SPEEDA, Lead data"},
-	{"Xcitec"                             , 97, 25, 60,  0, 0, 0, ""},
-	{"Fornet International Pte Ltd"       , 97, 26,  0,  0, 0, 0, "COMPUSA, Cdhouse"},
-	{"Postech Corporation"                , 97, 26, 10,  0, 0, 0, "Mr.Platinum"},
-	{"SKC Co Ltd."                        , 97, 26, 20,  0, 0, 0, "Infinite"},
-	{"Fuji Photo Film Co,Ltd."            , 97, 26, 40,  0, 0, 0, ""},
-	{"Lead Data Inc."                     , 97, 26, 50,  0, 0, 0, "SONY, Gigastorage, MIRAGE"},
-	{"CMC Magnetics Corporation"          , 97, 26, 60,  0, 0, 0, "Daxon, Verbatim, Memorex, Bi-Winner, PLEXTOR, YAMAHA, Melody, Office DEPOT, Philips, eMARK, imation, HyperMedia, Samsung, Shintaro, Techworks"},
-	{"Ricoh Company Limited"              , 97, 27,  0,  0, 0, 0, "Sony, Digital Storage, Csita"},
-	{"Plasmon Data Systems Ltd"           , 97, 27, 10,  0, 0, 0, "Ritek, TDK, EMTEC, ALPHAPET, MANIA"},
-	{"Princo Corporation"                 , 97, 27, 20,  0, 0, 0, ""},
-	{"Pioneer"                            , 97, 27, 30,  0, 0, 0, ""},
-	{"Eastman Kodak Company"              , 97, 27, 40,  0, 0, 0, ""},
-	{"Mitsui Chemicals Inc."              , 97, 27, 50,  0, 0, 0, "MAM-A, TDK"},
-	{"Ricoh Company Limited"              , 97, 27, 60,  0, 0, 0, "Ritek"},
-	{"Gigastorage Corporation"            , 97, 28, 10,  0, 0, 0, "MaxMax, Nan-Ya"},
-	{"Multi Media Masters&Machinary SA"   , 97, 28, 20,  0, 0, 0, "King, Mmirex"},
-	{"Ritek Corp"                         , 97, 31,  0,  0, 0, 0, "TDK"},
-	{"Grand Advance Technology Sdn. Bhd." , 97, 31, 30,  0, 0, 0, ""},
-	{"TDK Corporation"                    , 97, 32, 00,  0, 0, 0, ""},
-	{"Prodisc Technology Inc."            , 97, 32, 10,  0, 0, 0, "Smartbuy, Mitsubishi, Digmaster, LG, Media Market"},
-	{"Mitsubishi Chemical Corporation"    , 97, 34, 20,  0, 0, 0, "YAMAHA, Verbatim"},
-	{"Mitsui Chemicals Inc."              , 97, 48, 50, 0, 0, 0, ""},
-	{"TDK Corporation"                    , 97, 49,  0, 0, 0, 0, ""},
-	{"", 0, 0, 0, 0, 0, 0, ""}
+	{"SKC",                                 96, 40,  0,  ""},
+	{"Ritek Corp"                         , 96, 43, 30,  ""},
+	{"TDK / Ritek"                        , 97, 10,  0,  "TRAXDATA"},
+	{"TDK Corporation"                    , 97, 15,  0,  ""},
+	{"Ritek Corp"                         , 97, 15, 10,  "7-plus, Aopen, PONY, Power Source, TDK, TRAXDATA, HiCO, PHILIPS, Primdisc, Victor.JVC, OPTI STORAGE, Samsung"},
+	{"Mitsubishi Chemical Corporation"    , 97, 15, 20,  ""},
+	{"Nan-Ya Plastics Corporation"        , 97, 15, 30,  "Hatron, MMore, Acer, LITEON"},
+	{"Delphi"                             , 97, 15, 50,  ""},
+	{"Shenzhen SG&SAST"                   , 97, 16, 20,  ""},
+	{"Moser Baer India Limited"           , 97, 17,  0,  "EMTEC, Intenso, YAKUMO, PLATINUM, Silver Circle"},
+	{"SKY media Manufacturing SA"         , 97, 17, 10,  ""},
+	{"Wing"                               , 97, 18, 10,  ""},
+	{"DDT"                                , 97, 18, 20,  ""},
+	{"Daxon Technology Inc. / Acer"       , 97, 22, 60,  "Maxmax, Diamond Data, BenQ, gold, SONY"},
+	{"Taiyo Yuden Company Limited"        , 97, 24,  0,  "Maxell, FUJIFILM, SONY"},
+	{"Sony Corporation"                   , 97, 24, 10,  "LeadData, Imation"},
+	{"Computer Support Italcard s.r.l"    , 97, 24, 20,  ""},
+	{"Unitech Japan Inc."                 , 97, 24, 30,  ""},
+	{"MPO, France"                        , 97, 25,  0,  "TDK"},
+	{"Hitachi Maxell Ltd."                , 97, 25, 20,  ""},
+	{"Infodisc Technology Co,Ltd."        , 97, 25, 30,  "MEMOREX, SPEEDA, Lead data"},
+	{"Xcitec"                             , 97, 25, 60,  ""},
+	{"Fornet International Pte Ltd"       , 97, 26,  0,  "COMPUSA, Cdhouse"},
+	{"Postech Corporation"                , 97, 26, 10,  "Mr.Platinum"},
+	{"SKC Co Ltd."                        , 97, 26, 20,  "Infinite"},
+	{"Fuji Photo Film Co,Ltd."            , 97, 26, 40,  ""},
+	{"Lead Data Inc."                     , 97, 26, 50,  "SONY, Gigastorage, MIRAGE"},
+	{"CMC Magnetics Corporation"          , 97, 26, 60,  "Daxon, Verbatim, Memorex, Bi-Winner, PLEXTOR, YAMAHA, Melody, Office DEPOT, Philips, eMARK, imation, HyperMedia, Samsung, Shintaro, Techworks"},
+	{"Ricoh Company Limited"              , 97, 27,  0,  "Sony, Digital Storage, Csita"},
+	{"Plasmon Data Systems Ltd"           , 97, 27, 10,  "Ritek, TDK, EMTEC, ALPHAPET, MANIA"},
+	{"Princo Corporation"                 , 97, 27, 20,  ""},
+	{"Pioneer"                            , 97, 27, 30,  ""},
+	{"Eastman Kodak Company"              , 97, 27, 40,  ""},
+	{"Mitsui Chemicals Inc."              , 97, 27, 50,  "MAM-A, TDK"},
+	{"Ricoh Company Limited"              , 97, 27, 60,  "Ritek"},
+	{"Gigastorage Corporation"            , 97, 28, 10,  "MaxMax, Nan-Ya"},
+	{"Multi Media Masters&Machinary SA"   , 97, 28, 20,  "King, Mmirex"},
+	{"Ritek Corp"                         , 97, 31,  0,  "TDK"},
+	{"Grand Advance Technology Sdn. Bhd." , 97, 31, 30,  ""},
+	{"TDK Corporation"                    , 97, 32, 00,  ""},
+	{"Prodisc Technology Inc."            , 97, 32, 10,  "Smartbuy, Mitsubishi, Digmaster, LG, Media Market"},
+	{"Mitsubishi Chemical Corporation"    , 97, 34, 20,  "YAMAHA, Verbatim"},
+	{"Mitsui Chemicals Inc."              , 97, 48, 50, ""},
+	{"TDK Corporation"                    , 97, 49,  0, ""},
+	{"", 0, 0, 0, ""}
 	};
 
 	int i, f_li_0;
@@ -173,7 +170,6 @@ char *burn_guess_cd_manufacturer(int m_li, int s_li, int f_li,
 /* ts A90904 */
 struct dvd_mid_record {
 	char *mc1;
-	char *mc2;
 	int mc1_sig_len;
 	char *manufacturer;
 };
@@ -192,49 +188,49 @@ char *burn_guess_manufacturer(int prf,
 	                   Especially: ' ' -> '_' , {"_%/" unprintables -> %XY)
 	*/
 	static dvd_mid_record_t mid_list[]= {
-	{"AML",      "",    8, "UML"},
-	{"BeAll",    "",    5, "BeAll Developers, Inc."},
-	{"CMC",      "",    3, "CMC Magnetics Corporation"},
-	{"DAXON",    "",    5, "Daxon Technology Inc. / Acer"},
-	{"Daxon",    "",    5, "Daxon Technology Inc. / Acer"},
-	{"FUJI",     "",    4, "Fujifilm Holdings Corporation"},
-	{"INFODISC", "",    8, "New Star Digital Co., Ltd."},
-	{"INFOME",   "",    6, "InfoMedia Inc."},
-	{"ISMMBD",   "",    6, "Info Source Multi Media Ltd."},
-	{"JVC",      "",    3, "JVC Limited"},
-	{"KIC01RG",  "",    7, "AMC"},
-	{"LD",       "",    8, "Lead Data Inc."},
-	{"LGE",      "",    3, "LG Electronics"},
-	{"MAM",      "",    8, "Mitsui Advanced Media, Inc. Europe"},
-	{"MAXELL",   "",    6, "Hitachi Maxell Ltd."},
-	{"MBI",      "",    3, "Moser Baer India Limited"},
-	{"MCC",      "",    8, "Mitsubishi Chemical Corporation"},
-	{"MCI",      "",    8, "Mitsui Chemicals Inc."},
-	{"MEI",      "",    3, "Panasonic Corporation"},
-	{"MKM",      "",    3, "Mitsubishi Kagaku Media Co."},
-	{"MMC",      "",    8, "Mitsubishi Kagaku Media Co."},
-	{"MXL",      "",    8, "Hitachi Maxell Ltd."},
-	{"NANYA",    "",    5, "Nan-Ya Plastics Corporation"},
-	{"NSD",      "",    8, "NESA International Inc."},
-	{"OPTODISC", "",    8, "Optodisc Technology Corporation"},
-	{"OTCBDR",   "",    8, "Optodisc Technology Corporation"},
-	{"PHILIP",   "",    8, "Moser Baer India Limited"},
-	{"PHILIPS",  "",    8, "Philips"},
-	{"PRINCO",   "",    6, "Princo Corporation"},
-	{"PRODISC",  "",    7, "Prodisc Technology Inc."},
-	{"Prodisc",  "",    7, "Prodisc Technology Inc."},
-	{"PVC",      "",    3, "Pioneer"},
-	{"RICOHJPN", "",    8, "Ricoh Company Limited"},
-	{"RITEK",    "",    5, "Ritek Corp"},
-	{"SONY",     "",    4, "Sony Corporation"},
-	{"TDK",      "",    3, "TDK Corporation"},
-	{"TT",       "",    8, "TDK Corporation"},
-	{"TY",       "",    8, "Taiyo Yuden Company Limited"},
-	{"TYG",      "",    3, "Taiyo Yuden Company Limited"},
-	{"UTJR001",  "",    7, "Unifino Inc."},
-	{"VERBAT",   "",    5, "Mitsubishi Kagaku Media Co."},
-	{"YUDEN",    "",    5, "Taiyo Yuden Company Limited"},
-	{"", "", 0, ""}
+	{"AML",         8, "UML"},
+	{"BeAll",       5, "BeAll Developers, Inc."},
+	{"CMC",         3, "CMC Magnetics Corporation"},
+	{"DAXON",       5, "Daxon Technology Inc. / Acer"},
+	{"Daxon",       5, "Daxon Technology Inc. / Acer"},
+	{"FUJI",        4, "Fujifilm Holdings Corporation"},
+	{"INFODISC",    8, "New Star Digital Co., Ltd."},
+	{"INFOME",      6, "InfoMedia Inc."},
+	{"ISMMBD",      6, "Info Source Multi Media Ltd."},
+	{"JVC",         3, "JVC Limited"},
+	{"KIC01RG",     7, "AMC"},
+	{"LD",          8, "Lead Data Inc."},
+	{"LGE",         3, "LG Electronics"},
+	{"MAM",         8, "Mitsui Advanced Media, Inc. Europe"},
+	{"MAXELL",      6, "Hitachi Maxell Ltd."},
+	{"MBI",         3, "Moser Baer India Limited"},
+	{"MCC",         8, "Mitsubishi Chemical Corporation"},
+	{"MCI",         8, "Mitsui Chemicals Inc."},
+	{"MEI",         3, "Panasonic Corporation"},
+	{"MKM",         3, "Mitsubishi Kagaku Media Co."},
+	{"MMC",         8, "Mitsubishi Kagaku Media Co."},
+	{"MXL",         8, "Hitachi Maxell Ltd."},
+	{"NANYA",       5, "Nan-Ya Plastics Corporation"},
+	{"NSD",         8, "NESA International Inc."},
+	{"OPTODISC",    8, "Optodisc Technology Corporation"},
+	{"OTCBDR",      8, "Optodisc Technology Corporation"},
+	{"PHILIP",      8, "Moser Baer India Limited"},
+	{"PHILIPS",     8, "Philips"},
+	{"PRINCO",      6, "Princo Corporation"},
+	{"PRODISC",     7, "Prodisc Technology Inc."},
+	{"Prodisc",     7, "Prodisc Technology Inc."},
+	{"PVC",         3, "Pioneer"},
+	{"RICOHJPN",    8, "Ricoh Company Limited"},
+	{"RITEK",       5, "Ritek Corp"},
+	{"SONY",        4, "Sony Corporation"},
+	{"TDK",         3, "TDK Corporation"},
+	{"TT",          8, "TDK Corporation"},
+	{"TY",          8, "Taiyo Yuden Company Limited"},
+	{"TYG",         3, "Taiyo Yuden Company Limited"},
+	{"UTJR001",     7, "Unifino Inc."},
+	{"VERBAT",      5, "Mitsubishi Kagaku Media Co."},
+	{"YUDEN",       5, "Taiyo Yuden Company Limited"},
+	{"", 0, ""}
 	};
 
 	if (media_code2 != NULL &&
