@@ -344,7 +344,7 @@ int isoburn_is_intermediate_dvd_rw(struct burn_drive *d, int flag)
 static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
                                  int flag)
 {
- int ret, lba, nwa, profile, readonly= 0, role, random_access;
+ int ret, profile, readonly= 0, role, random_access;
  int emulation_started= 0;
  struct burn_multi_caps *caps= NULL;
  struct isoburn_toc_entry *t;
@@ -356,6 +356,10 @@ static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
  char msg[80];
  enum burn_disc_status s;
 
+#ifndef Hardcoded_cd_rW
+ int lba, nwa;
+#endif
+
  s= burn_disc_get_status(d);
  profile_name[0]= 0;
  ret= burn_disc_get_profile(d, &profile, profile_name);
@@ -417,7 +421,13 @@ static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
     /* >>> recognize unsuitable media (but allow read-only media) */;
 
    if(readonly && s != BURN_DISC_EMPTY) {
+
+     /* >>> ts B10712: This maps BURN_DISC_UNSUITABLE to BURN_DISC_FULL
+                       which can hardly be correct in general.
+        ??? What reason does this have ?
+     */
      (*o)->fabricated_disc_status= BURN_DISC_FULL;
+
      /* This might be overwriteable media in a -ROM drive.
         Pitfall:
         Multi-session media which bear a xorriso image for overwriteables
@@ -774,6 +784,7 @@ int isoburn_disc_track_lba_nwa(struct burn_drive *d,
 {
  int ret;
  struct isoburn *o;
+ enum burn_disc_status s;
 
 #ifdef Hardcoded_cd_rW
  /* <<< A70929 : hardcoded CD-RW with fabricated -msinfo */
@@ -793,6 +804,10 @@ int isoburn_disc_track_lba_nwa(struct burn_drive *d,
  }
  if(burn_drive_get_drive_role(d) != 1)
    return(1);
+
+ s= isoburn_disc_get_status(d);
+ if(s == BURN_DISC_BLANK) /* We do not believe in anything but nwa = lba = 0 */
+   return(1);
  return(burn_disc_track_lba_nwa(d, opts, trackno, lba, nwa));
 }
 
