@@ -5,7 +5,7 @@
  *
  * Implementation of a generic checksum interface, used in JTE.
  *
- * GNU GPL v2
+ * GNU GPL v2+
  */
 
 #ifdef HAVE_CONFIG_H
@@ -17,7 +17,15 @@
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
+
+#ifdef HAVE_STDINT_H
 #include <stdint.h>
+#else
+#ifdef HAVE_INTTYPES_H
+#include <inttypes.h>
+#endif
+#endif
+
 #include "md5.h"
 #include "sha1.h"
 #include "sha256.h"
@@ -488,7 +496,7 @@ int parse_checksum_algo(char *arg, int *algo)
         {
             for (i = 0; i < NUM_CHECKSUMS; i++)
             {
-                if (len == strlen(algorithms[i].name) &&
+                if (len == (int) strlen(algorithms[i].name) &&
                     !strncasecmp(start_ptr, algorithms[i].name, len))
                 {
                     match = 1;
