@@ -48,9 +48,10 @@ static const char *un0(const char *text)
 int Xorriso_auto_driveadr(struct XorrisO *xorriso, char *adr, char *result,
                           int flag)
 {
- int ret, is_known_mmc= 0;
+ int ret, is_known_mmc= 0, does_exist= 0;
  char *path_pt, *libburn_adr= NULL;
  char *abs_pt, *abs_adr= NULL;
+ struct stat stbuf;
 
  Xorriso_alloc_meM(libburn_adr, char, BURN_DRIVE_ADR_LEN + SfileadrL);
  Xorriso_alloc_meM(abs_adr, char, SfileadrL);
@@ -77,6 +78,7 @@ int Xorriso_auto_driveadr(struct XorrisO *xorriso, char *adr, char *result,
  }
 
  is_known_mmc= burn_drive_convert_fs_adr(path_pt, libburn_adr);
+ does_exist= (stat(path_pt, &stbuf) != -1);
  Xorriso_process_msg_queues(xorriso,0);
 
  ret= Xorriso_is_in_patternlist(xorriso, xorriso->drive_whitelist, path_pt, 0);
@@ -106,15 +108,20 @@ int Xorriso_auto_driveadr(struct XorrisO *xorriso, char *adr, char *result,
    if(ret) {
      strcpy(xorriso->info_text, "Drive address ");
      Text_shellsafe(adr, xorriso->info_text, 1);
-     strcat(xorriso->info_text,
-            " rejected because: not MMC and -drive_class 'risky' ");
+     strcat(xorriso->info_text, " rejected because: ");
+     if(does_exist)
+       strcat(xorriso->info_text, "not MMC");
+     else
+       strcat(xorriso->info_text, "not existing");
+     strcat(xorriso->info_text, " and -drive_class 'risky' ");
      Text_shellsafe(Xorriso_get_pattern(xorriso,xorriso->drive_greylist,
                                         ret - 1, 0),
                     xorriso->info_text, 1);
      Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
-     Xorriso_msgs_submit(xorriso, 0,
-                   "If the address is a legitimate target, prepend \"stdio:\"",
-                   0, "HINT", 0);
+     sprintf(xorriso->info_text,
+             "If the address is a legitimate %s, prepend \"stdio:\"",
+             does_exist ? "target" : "address for a new regular file");
+     Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "HINT", 0);
      {ret= 0; goto ex;}
    }
  }
@@ -157,7 +164,8 @@ ex:;
            2=success, but not writeable with bit1
            3=success, but not blank and not ISO with bit0
 */
-int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, int flag)
+int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, char *show_adr,
+                         int flag)
 {
  int ret, hret, not_writeable= 0, has_what, aquire_flag, load_lba, ext;
  int lba, track, session, params_flag, adr_mode, read_ret;
@@ -168,15 +176,23 @@ int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, int flag)
  IsoImage *volset = NULL;
  IsoNode *root_node;
  struct isoburn_read_opts *ropts= NULL;
- char *libburn_adr= NULL, *boot_fate, *sev;
+ char *libburn_adr= NULL, *off_adr= NULL, *boot_fate, *sev;
  size_t value_length;
  char *value= NULL;
  double num;
  char volid[33], *adr_data= NULL, *adr_pt;
 
  Xorriso_alloc_meM(libburn_adr, char, SfileadrL);
+ Xorriso_alloc_meM(off_adr, char, SfileadrL);
  Xorriso_alloc_meM(adr_data, char, 163);
 
+ if(show_adr == NULL) {
+   show_adr= adr;
+   ret= burn_drive_convert_fs_adr(adr, off_adr);
+   if(ret > 0)
+     adr= off_adr;
+ }
+
  if((flag&3)==0) { 
    sprintf(xorriso->info_text, 
          "XORRISOBURN program error : Xorriso_aquire_drive bit0+bit1 not set");
@@ -310,8 +326,11 @@ int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, int flag)
 
  if(flag&2) {
    xorriso->out_drive_handle= dinfo;
-   if(Sfile_str(xorriso->outdev, adr, 0)<=0)
+   if(Sfile_str(xorriso->outdev, show_adr, 0)<=0)
      {ret= -1; goto ex;}
+   ret= burn_drive_convert_fs_adr(adr, xorriso->outdev_off_adr);
+   if(ret <= 0)
+     xorriso->outdev_off_adr[0]= 0;
    if(state != BURN_DISC_BLANK && state != BURN_DISC_APPENDABLE) {
      sprintf(xorriso->info_text, "Disc status unsuitable for writing");
      Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "NOTE", 0);
@@ -320,8 +339,11 @@ int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, int flag)
  }
  if(flag&1) {
    xorriso->in_drive_handle= dinfo;
-   if(Sfile_str(xorriso->indev, adr, 0)<=0)
+   if(Sfile_str(xorriso->indev, show_adr, 0)<=0)
      {ret= -1; goto ex;}
+   ret= burn_drive_convert_fs_adr(adr, xorriso->indev_off_adr);
+   if(ret <= 0)
+     xorriso->indev_off_adr[0]= 0;
  } else if(flag&2) {
    if(xorriso->in_volset_handle==NULL) {
      /* No volume loaded: create empty one */
@@ -538,6 +560,7 @@ ex:
  }
  if(ropts!=NULL)
    isoburn_ropt_destroy(&ropts, 0);
+ Xorriso_free_meM(off_adr);
  Xorriso_free_meM(libburn_adr);
  Xorriso_free_meM(adr_data);
  return(ret);
@@ -619,6 +642,7 @@ int Xorriso_give_up_drive(struct XorrisO *xorriso, int flag)
    }
    xorriso->out_drive_handle= NULL;
    xorriso->outdev[0]= 0;
+   xorriso->outdev_off_adr[0]= 0;
  } else if((flag&1) && xorriso->out_drive_handle!=NULL) {
    ret= Xorriso_create_empty_iso(xorriso, 0);
    if(ret<=0)
@@ -685,17 +709,22 @@ ex:;
 }
 
 
-/* @param flag bit0+1= what to aquire after giving up outdev
+/* @param flag bit0+1= what to give up and re-aquire by the address of outdev
                        0=none, 1=indev, 2=outdev, 3=both
 */
 int Xorriso_reaquire_outdev(struct XorrisO *xorriso, int flag)
 {
  int ret, aq_flag;
- char *drive_name= NULL;
+ char *drive_name= NULL, *off_name= NULL;
 
  Xorriso_alloc_meM(drive_name, char, SfileadrL);
+ Xorriso_alloc_meM(off_name, char, SfileadrL);
  aq_flag= flag&3;
  strcpy(drive_name, xorriso->outdev);
+ if(xorriso->outdev_off_adr[0])
+   strcpy(off_name, xorriso->outdev_off_adr);
+ else
+   strcpy(off_name, drive_name);
  Xorriso_give_up_drive(xorriso, aq_flag);
  if(aq_flag==0) { 
    sprintf(xorriso->info_text,"Gave up -outdev ");
@@ -705,17 +734,26 @@ int Xorriso_reaquire_outdev(struct XorrisO *xorriso, int flag)
  }
  sprintf(xorriso->info_text,"Re-aquiring -outdev ");
  Text_shellsafe(drive_name, xorriso->info_text, 1);
+ if(strcmp(drive_name, off_name) != 0) {
+   strcat(xorriso->info_text, "  (");
+   Text_shellsafe(off_name, xorriso->info_text, 1);
+   strcat(xorriso->info_text, ")");
+ }
  Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "NOTE", 0);
- ret= Xorriso_aquire_drive(xorriso, drive_name, aq_flag); 
+ ret= Xorriso_aquire_drive(xorriso, off_name, drive_name, aq_flag); 
  if(ret<=0) {
    sprintf(xorriso->info_text,"Could not re-aquire -outdev ");
-   Text_shellsafe(xorriso->outdev, xorriso->info_text, 1);
+   Text_shellsafe(drive_name, xorriso->info_text, 1);
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
    goto ex;
  }
+ strcpy(xorriso->outdev, drive_name);
+ if(strcmp(xorriso->outdev, xorriso->indev) == 0)
+   strcpy(xorriso->indev, drive_name);
  ret= 1;
 ex:;
  Xorriso_free_meM(drive_name);
+ Xorriso_free_meM(off_name);
  return(ret);
 }
 
