@@ -770,3 +770,94 @@ jte_failed:
 
 }
 
+
+int Xorriso_list_extras_result(struct XorrisO *xorriso, char *mode,
+                               char *what, int flag)
+{
+ if(mode[0] != 0 && strcmp(mode, "all") != 0) {
+   if(strcmp(mode, what) != 0 &&
+      (mode[0] != '-' || strcmp(mode + 1, what) != 0)) 
+     return(2);
+ }
+ Xorriso_result(xorriso, 0);
+ return(1);
+}
+
+
+int Xorriso_list_extras(struct XorrisO *xorriso, char *mode, int flag)
+{
+ int ret;
+
+ if(strcmp(mode, "codes") == 0) {
+   sprintf(xorriso->result_line,
+        "List of xorriso extra feature codes. Usable with or without dash.\n");
+   Xorriso_result(xorriso, 0);
+   sprintf(xorriso->result_line, "Local ACL    : -acl\n");
+   Xorriso_result(xorriso, 0);
+   sprintf(xorriso->result_line, "Local xattr  : -xattr\n");
+   Xorriso_result(xorriso, 0);
+   sprintf(xorriso->result_line, "Jigdo files  : -jigdo\n");
+   Xorriso_result(xorriso, 0);
+   sprintf(xorriso->result_line, "zisofs       : -zisofs\n");
+   Xorriso_result(xorriso, 0);
+   sprintf(xorriso->result_line, "Ext. filters : -external_filter\n");
+   Xorriso_result(xorriso, 0);
+   sprintf(xorriso->result_line, "DVD obs 64 kB: -dvd_obs\n");
+   Xorriso_result(xorriso, 0);
+   sprintf(xorriso->result_line, "Readline     : -use_readline\n");
+   Xorriso_result(xorriso, 0);
+   return(1);
+ }
+ sprintf(xorriso->result_line,
+         "List of xorriso extra features. yes = enabled , no = disabled\n");
+ Xorriso_list_extras_result(xorriso, mode, "list_extras", 0);
+
+ ret= iso_local_attr_support(3);
+ sprintf(xorriso->result_line, "Local ACL    : %s\n", ret & 1 ? "yes" : "no");
+ Xorriso_list_extras_result(xorriso, mode, "acl", 0);
+ sprintf(xorriso->result_line, "Local xattr  : %s\n", ret & 2 ? "yes" : "no");
+ Xorriso_list_extras_result(xorriso, mode, "xattr", 0);
+ 
+ sprintf(xorriso->result_line, "Jigdo files  : %s\n",
+#ifdef Xorriso_with_libjtE
+         "yes");
+#else
+         "no");
+#endif
+ Xorriso_list_extras_result(xorriso, mode, "jigdo", 0);
+
+ ret= iso_file_add_zisofs_filter(NULL, 4);
+ sprintf(xorriso->result_line, "zisofs       : %s\n", ret == 2 ? "yes" : "no");
+ Xorriso_list_extras_result(xorriso, mode, "zisofs", 0);
+
+ sprintf(xorriso->result_line, "Ext. filters : %s\n",
+#ifdef Xorriso_allow_external_filterS
+#ifdef Xorriso_allow_extf_suiD
+         "yes , setuid allowed");
+#else
+         "yes , setuid banned");
+#endif
+#else
+         "no");
+#endif
+ Xorriso_list_extras_result(xorriso, mode, "external_filter", 0);
+
+ sprintf(xorriso->result_line, "DVD obs 64 kB: %s\n",
+#ifdef Xorriso_dvd_obs_default_64K
+         "yes");
+#else
+         "no");
+#endif
+ Xorriso_list_extras_result(xorriso, mode, "dvd_obs", 0);
+
+ sprintf(xorriso->result_line, "Readline     : %s\n",
+#ifdef Xorriso_with_readlinE
+         "yes");
+#else
+         "no");
+#endif
+ Xorriso_list_extras_result(xorriso, mode, "use_readline", 0);
+
+ return(1);
+}
+
