@@ -89,6 +89,9 @@ int Xorriso__hide_mode(char *mode, int flag);
 
 char *Xorriso__hide_mode_text(int hide_mode, int flag);
 
+/* @return 0=truncated, 1=ok
+*/
+int Xorriso__to_upper(char *in, char *out, int out_size, int flag);
 
 #endif /* ! Xorriso_pvt_misc_includeD */
 
