@@ -1795,9 +1795,6 @@ int Xorriso_option_close_filter_list(struct XorrisO *xorriso, int flag)
 int Xorriso_option_commit(struct XorrisO *xorriso, int flag)
 {
  int ret;
- char *newdev= NULL;
-
- Xorriso_alloc_meM(newdev, char, SfileadrL);
 
  if(!xorriso->volset_change_pending) {
    sprintf(xorriso->info_text, "-commit: No image modifications pending");
@@ -1822,16 +1819,16 @@ int Xorriso_option_commit(struct XorrisO *xorriso, int flag)
    {ret= 1; goto ex;}
  if(Sregex_string(&(xorriso->in_charset), xorriso->out_charset, 0) <= 0)
    {ret= -1; goto ex;}
- strcpy(newdev, xorriso->outdev);
  if(xorriso->grow_blindly_msc2>=0)
    ret= Xorriso_option_dev(xorriso, "", 3|4);
  else {
    xorriso->displacement= 0;
    xorriso->displacement_sign= 0;
-   ret= Xorriso_option_dev(xorriso, newdev, 3|4);
+   ret= Xorriso_reaquire_outdev(xorriso, 3);
+   if(xorriso->in_drive_handle == NULL)
+     xorriso->image_start_mode= 0; /* session setting is invalid by now */
  }
 ex:;
- Xorriso_free_meM(newdev);
  return(ret);
 }
 
