@@ -466,7 +466,7 @@ int Xorriso_count_args(struct XorrisO *xorriso, int argc, char **argv,
     "dummy","dvd_obs","early_stdio_test", "eject",
     "iso_rr_pattern","follow","format","fs","gid","grow_blindly","hardlinks",
     "history","indev","in_charset","joliet",
-    "list_delimiter","list_profiles","local_charset",
+    "list_delimiter","list_extras","list_profiles","local_charset",
     "mark","md5","mount_opts","not_leaf","not_list","not_mgt",
     "options_from_file","osirrox","outdev","out_charset","overwrite",
     "pacifier","padding","path_list","pathspecs","pkt_output",
@@ -1023,6 +1023,10 @@ next_command:;
    (*idx)++;
    ret= Xorriso_option_list_delimiter(xorriso, arg1, 0);
 
+ } else if(strcmp(cmd, "list_extras") == 0) {
+   (*idx)++;
+   ret= Xorriso_option_list_extras(xorriso, arg1, 0);
+
  } else if(strcmp(cmd,"list_formats")==0) {
    ret= Xorriso_option_list_formats(xorriso, 0);
 
