@@ -1301,11 +1301,12 @@ int Xorriso_status(struct XorrisO *xorriso, char *filter, FILE *fp, int flag)
  if(xorriso->allow_restore == -1)
    sprintf(line,"-osirrox %s\n", mode_pt);
  else
-   sprintf(line,"-osirrox %s:%s:%s:%s:%s\n", mode_pt,
+   sprintf(line,"-osirrox %s:%s:%s:%s:%s:%s\n", mode_pt,
          xorriso->do_concat_split ? "concat_split_on" : "concat_split_off",
          xorriso->do_auto_chmod ? "auto_chmod_on" : "auto_chmod_off",
          xorriso->do_restore_sort_lba ? "sort_lba_on" : "sort_lba_off",
-         xorriso->drives_exclusive ? "o_excl_on" : "o_excl_off"
+         xorriso->drives_exclusive ? "o_excl_on" : "o_excl_off",
+         (xorriso->do_strict_acl & 1) ? "strict_acl_on" : "strict_acl_off"
         );
  if(!(is_default && no_defaults))
    Xorriso_status_result(xorriso,filter,fp,flag&2);
