@@ -61,10 +61,10 @@ struct XorrisO;
 */
 #define Xorriso_header_version_majoR  1
 #define Xorriso_header_version_minoR  1
-#define Xorriso_header_version_micrO  4
+#define Xorriso_header_version_micrO  6
 
 
-/** Eventually something like ".pl01" to indicate a bug fix. Normally empty.
+/** If needed: Something like ".pl01" to indicate a bug fix. Normally empty.
     @since 0.5.8
 */
 #define Xorriso_program_patch_leveL ""
@@ -920,6 +920,9 @@ int Xorriso_option_joliet(struct XorrisO *xorriso, char *mode, int flag);
 int Xorriso_option_list_delimiter(struct XorrisO *xorriso, char *text,
                                   int flag);
 
+/* Option -list_extras */
+int Xorriso_option_list_extras(struct XorrisO *xorriso, char *mode, int flag);
+
 /* Option -list_formats */
 int Xorriso_option_list_formats(struct XorrisO *xorriso, int flag);
 
