@@ -19,7 +19,7 @@
 */
 #define xorriso_libisoburn_req_major  1
 #define xorriso_libisoburn_req_minor  1
-#define xorriso_libisoburn_req_micro  4
+#define xorriso_libisoburn_req_micro  6
 
 
 struct SpotlisT;          /* List of intervals with different read qualities */
@@ -37,7 +37,8 @@ int Xorriso_create_empty_iso(struct XorrisO *xorriso, int flag);
                bit1=aquire as libburn output drive (as isoburn drive if bit0)
    @return <=0 failure , 1=success , 2=neither readable or writeable
 */
-int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, int flag);
+int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, char *show_adr,
+                         int flag);
 
 int Xorriso_give_up_drive(struct XorrisO *xorriso, int flag);
 
@@ -399,6 +400,14 @@ int Xorriso_getfacl(struct XorrisO *xorriso, void *node,
 int Xorriso_getfattr(struct XorrisO *xorriso, void *in_node, char *path,
                      char **attr_text, int flag);
 
+int Xorriso_list_extattr(struct XorrisO *xorriso, void *in_node, char *path,
+                         char *show_path, char *mode, int flag);
+
+int Xorriso_append_extattr_comp(struct XorrisO *xorriso,
+                                char *comp, size_t comp_len, 
+                                char *mode, int flag);
+
+
 /* Calls iso_image_set_ignore_aclea() according to  xorriso->do_aaip */
 int Xorriso_set_ignore_aclea(struct XorrisO *xorriso, int flag);
 
@@ -584,5 +593,7 @@ int Xorriso_set_signal_handling(struct XorrisO *xorriso, int flag);
 */
 int Xorriso_close_damaged(struct XorrisO *xorriso, int flag);
 
+int Xorriso_list_extras(struct XorrisO *xorriso, char *mode, int flag);
+
 #endif /* Xorrisoburn_includeD */
 
